Index — Frozen-Flask 0.14 documentation

# Index

A | F | I | R | S | W

## A

all_urls() (flask_frozen.Freezer method)

## F

flask_frozen (module) freeze() (flask_frozen.Freezer method) | Freezer (class in flask_frozen)

## I

init_app() (flask_frozen.Freezer method)

## R

register_generator() (flask_frozen.Freezer method) relative_url_for() (in module flask_frozen) | root (flask_frozen.Freezer attribute) run() (flask_frozen.Freezer method)

## S

serve() (flask_frozen.Freezer method)

## W

walk_directory() (in module flask_frozen)